Index: /trunk/include/VBox/vm.h
===================================================================
--- /trunk/include/VBox/vm.h	(revision 22706)
+++ /trunk/include/VBox/vm.h	(revision 22707)
@@ -973,5 +973,5 @@
 /** @def VM_REM_SIZE
  * Must be multiple of 32 and coherent with REM_ENV_SIZE from REMInternal.h. */
-# define VM_REM_SIZE        0x10A00
+# define VM_REM_SIZE        0x11100
         char        padding[VM_REM_SIZE];   /* multiple of 32 */
     } rem;
Index: /trunk/src/VBox/VMM/REMInternal.h
===================================================================
--- /trunk/src/VBox/VMM/REMInternal.h	(revision 22706)
+++ /trunk/src/VBox/VMM/REMInternal.h	(revision 22707)
@@ -175,5 +175,5 @@
     /** Array of recorded handler noticications.
      * These are replayed when entering REM. */
-    REMHANDLERNOTIFICATION  aHandlerNotifications[32];
+    REMHANDLERNOTIFICATION  aHandlerNotifications[64];
     volatile uint32_t       idxPendingList;
     volatile uint32_t       idxFreeList;
Index: /trunk/src/VBox/VMM/VMMAll/REMAll.cpp
===================================================================
--- /trunk/src/VBox/VMM/VMMAll/REMAll.cpp	(revision 22706)
+++ /trunk/src/VBox/VMM/VMMAll/REMAll.cpp	(revision 22707)
@@ -214,5 +214,5 @@
 
     /*
      * Less than 20 items means we should flush.
      */
     uint32_t cFree = 0;
@@ -222,5 +222,5 @@
     {
         Assert(idx < RT_ELEMENTS(pVM->rem.s.aHandlerNotifications));
-        if (++cFree > 20)
+        if (++cFree >= 48)
             return;
     }
@@ -214,5 +214,5 @@
 
     /*
-     * Less than 20 items means we should flush.
+     * Less than 48 items means we should flush.
      */
     uint32_t cFree = 0;
